@@ -308,7 +308,7 @@ class PostEndpoints:
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.base_class.post_data(uri='AdditionalContractElementPost/*', data=base_body, return_key=None)
+        response = self.base_class.post_data(uri='AdditionalContractElementsPost/*', data=base_body, return_key=None)
         return response
 
     def post_basic_pay(self, data: dict, overload_fields: dict = None):
